@@ -1,3 +1,8 @@
+/**
+ * SPDX-FileCopyrightText: Copyright 2023-2024 Open Mobile Platform LLC <community@omp.ru>
+ * SPDX-License-Identifier: Proprietary
+ */
+
 #ifndef POLICYTYPE_H
 #define POLICYTYPE_H
 
@@ -18,8 +23,8 @@ enum PolicyType {
     CameraEnabled,
     LocationSettingsEnabled,
     OsUpdatesEnabled,
-    SideLoadingSettingsEnabled Q_DECL_DEPRECATED,
     DeveloperModeSettingsEnabled,
+    SideLoadingSettingsEnabled Q_DECL_DEPRECATED,
     ApplicationInstallationEnabled,
     WlanToggleEnabled,
     InternetSharingEnabled,
@@ -54,11 +59,13 @@ enum PolicyType {
     SimPinningSettingsEnabled,
     SimSlotsSettingsEnabled,
     DevelSuEnabled,
+    NfcToggleEnabled,
 };
 
 #ifdef  __cplusplus
 }
 }
+
 #endif
 
 #endif
